@@ -20,17 +20,17 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' @param varCount The variable which frequencies should be plotted.
 #' @param title Title of diagram as string. Example: \code{title=c("my title")}.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link{sji.setVariableLabels}}) for details).
+#'          (see \code{\link{set_var_labels}}) for details).
 #' @param weightBy A weight factor that will be applied to weight all cases from \code{varCount}.
-#'          default is \code{NULL}, so no weights are used.
+#'          Must be a vector of same length as \code{varCount}. Default is \code{NULL}, so no weights are used.
 #' @param weightByTitleString If a weight factor is supplied via the parameter \code{weightBy}, the diagram's title
 #'          may indicate this with a remark. Default is \code{NULL}, so the diagram's title will not be modified when
 #'          cases are weighted. Use a string as parameter, e.g.: \code{weightByTitleString=" (weighted)"}.
 #' @param interactionVar An interaction variable which can be used for box plots. Divides the observations in 
 #'          \code{varCount} into the factors (sub groups) of \code{interactionVar}. Only applies when parameter \code{"type"}
 #'          is \code{"box"} or \code{"violin"} (resp. their alternative strings like \code{"boxplot"}, \code{"boxplots"} or \code{"v"}).
-#' @param sort.frq Determines whether categories on x-axis should be order according to the frequencies or not. 
-#'          Default is \code{"none"}, so categories are not ordered by frequency. Use \code{"asc"} or
+#' @param sort.frq Determines whether categories on x-axis should be sorted according to the frequencies or not. 
+#'          Default is \code{"none"}, so categories are not sorted by frequency. Use \code{"asc"} or
 #'          \code{"desc"} for sorting categories ascending or descending in relation to the frequencies.
 #' @param type Specifies the type of distribution plot that will be plotted.
 #'          \itemize{
@@ -48,9 +48,9 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          \code{"dots"}).
 #' @param axisLabels.x Labels for the x-axis breaks.
 #'          Example: \code{axisLabels.x=c("Label1", "Label2", "Label3")}.
-#'          Note: If you use the \code{\link{sji.SPSS}} function and the \code{\link{sji.getValueLabels}} function, you receive a
-#'          list object with label string. The labels may also be passed as list object. They will be unlisted and
-#'          converted to character vector automatically.
+#'          Note: If you use the \code{\link{read_spss}} function and the \code{\link{get_val_labels}} function, you receive a
+#'          list object with label string. The labels may also be passed as list object. They will be coerced
+#'          to character vector automatically.
 #' @param interactionVarLabels Labels for the x-axis breaks when having interaction variables included.
 #'          These labels replace the \code{axisLabels.x}. Only applies, when using box or violin plots
 #'          (i.e. \code{"type"} is \code{"box"} or \code{"violin"}) and \code{interactionVar} is not \code{NULL}.
@@ -111,12 +111,12 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          are assigned to the x axis. By default, \code{""} is used, i.e. no title
 #'          is printed.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link{sji.setVariableLabels}}) for details).
+#'          (see \code{\link{set_var_labels}}) for details).
 #' @param axisTitle.y A label for the y axis. useful when plotting histograms with metric scales where no category labels
 #'          are assigned to the y axis. By default, \code{""} is used, i.e. no title
 #'          is printed.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link{sji.setVariableLabels}}) for details).
+#'          (see \code{\link{set_var_labels}}) for details).
 #' @param hist.skipZeros If \code{TRUE}, zero counts (categories with no answer) in \code{varCount} are omitted
 #'          when drawing histrograms, and the mapping is changed to \code{\link{stat_bin}}. Only applies to 
 #'          histograms (see \code{type}). Use this parameter to get identical results to the default
@@ -128,10 +128,10 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #'          If you set \code{startAxisAt} to 1, you may have zero counts if the lowest value of \code{varCount}
 #'          is larger than 1 and hence no bars plotted for these values in such cases.
 #' @param autoGroupAt A value indicating at which length of unique values of \code{varCount} the variable
-#'          is automatically grouped into smaller units (see \code{\link{sju.groupVar}}). If \code{varCount} has large 
+#'          is automatically grouped into smaller units (see \code{\link{group_var}}). If \code{varCount} has large 
 #'          numbers of unique values, too many bars for the graph have to be plotted. Hence it's recommended 
 #'          to group such variables. For example, if \code{autoGroupAt} is 50, i.e. if \code{varCount} has 50 and more unique values 
-#'          it will be grouped using \code{\link{sju.groupVar}} with \code{groupsize="auto"} parameter. By default, 
+#'          it will be grouped using \code{\link{group_var}} with \code{groupsize="auto"} parameter. By default, 
 #'          the maximum group count is 30. However, if \code{autoGroupAt} is less than 30, \code{autoGroupAt} 
 #'          groups are built. Default value for \code{autoGroupAt} is \code{NULL}, i.e. auto-grouping is off.
 #' @param coord.flip If \code{TRUE}, the x and y axis are swapped. Default is \code{FALSE}.
@@ -173,11 +173,11 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' # ---------------
 #' # bar plot with EUROFAMCARE sample dataset
 #' # dataset was importet from an SPSS-file, using:
-#' # efc <- sji.SPSS("efc.sav", enc="UTF-8")
+#' # efc <- read_spss("efc.sav", enc="UTF-8")
 #' # ---------------
 #' data(efc)
-#' efc.val <- sji.getValueLabels(efc)
-#' efc.var <- sji.getVariableLabels(efc)
+#' efc.val <- get_val_labels(efc)
+#' efc.var <- get_var_labels(efc)
 #' # you may use sjp.setTheme here to change axis textangle
 #' sjp.frq(as.factor(efc$e15relat), 
 #'         title=efc.var[['e15relat']],
@@ -185,8 +185,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' 
 #' # bar plot with EUROFAMCARE sample dataset
 #' # grouped variable
-#' ageGrp <- sju.groupVar(efc$e17age)
-#' ageGrpLab <- sju.groupVarLabels(efc$e17age)
+#' ageGrp <- group_var(efc$e17age)
+#' ageGrpLab <- group_labels(efc$e17age)
 #' sjp.frq(ageGrp,
 #'         title=efc.var[['e17age']],
 #'         axisLabels.x=ageGrpLab)
@@ -205,7 +205,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci",
 #' # -------------------------------------------------
 #' # auto-detection of value labels and variable names
 #' # -------------------------------------------------
-#' efc <- sji.setVariableLabels(efc, sji.getVariableLabels(efc))
+#' efc <- set_var_labels(efc, get_var_labels(efc))
 #' 
 #' # negative impact scale, ranging from 7-28, assuming that
 #' # variable scale (lowest value) starts with 1
@@ -344,11 +344,19 @@ sjp.frq <- function(varCount,
   #---------------------------------------------------
   # check whether variable should be auto-grouped
   #---------------------------------------------------
-  if (!is.null(autoGroupAt) && length(unique(varCount))>=autoGroupAt) {
+  if (!is.null(autoGroupAt) && length(unique(varCount)) >= autoGroupAt) {
     message(sprintf("Variable has %i unique values and was grouped...", length(unique(varCount))))
-    agcnt <- ifelse (autoGroupAt<30, autoGroupAt, 30)
-    axisLabels.x <- sju.groupVarLabels(varCount, groupsize="auto", autoGroupCount=agcnt)
-    varCount <- sju.groupVar(varCount, groupsize="auto", asNumeric=TRUE, autoGroupCount=agcnt)
+    # check for default auto-group-size or user-defined groups
+    agcnt <- ifelse (autoGroupAt < 30, autoGroupAt, 30)
+    # group axis labels
+    axisLabels.x <- group_labels(varCount, 
+                                 groupsize = "auto", 
+                                 autoGroupCount = agcnt)
+    # group variable
+    varCount <- group_var(varCount, 
+                          groupsize = "auto", 
+                          asNumeric = TRUE, 
+                          autoGroupCount = agcnt)
   }
   # --------------------------------------------------------
   # unlist labels
@@ -379,8 +387,8 @@ sjp.frq <- function(varCount,
     fpos <- which(df.frqci$frq == mydat$frq[ici])
     # found anything?
     if (!is.null(fpos) && length(fpos) > 0) {
-      mydat$lower.ci[ici] <- round(df.frqci$lower.ci[fpos])
-      mydat$upper.ci[ici] <- round(df.frqci$upper.ci[fpos])
+      mydat$lower.ci[ici] <- round(df.frqci$lower.ci[fpos][1])
+      mydat$upper.ci[ici] <- round(df.frqci$upper.ci[fpos][1])
     }
   }
   # --------------------------------------------------------
@@ -393,23 +401,23 @@ sjp.frq <- function(varCount,
     if (!is.null(weightByTitleString)) {
       title <- paste(title, weightByTitleString, sep="")
     }
-    title <- sju.wordwrap(title, breakTitleAt)    
+    title <- word_wrap(title, breakTitleAt)    
   }
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
   if (!is.null(axisTitle.x)) {
-    axisTitle.x <- sju.wordwrap(axisTitle.x, breakTitleAt)    
+    axisTitle.x <- word_wrap(axisTitle.x, breakTitleAt)    
   }
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
   if (!is.null(axisTitle.y)) {
-    axisTitle.y <- sju.wordwrap(axisTitle.y, breakTitleAt)    
+    axisTitle.y <- word_wrap(axisTitle.y, breakTitleAt)    
   }
   # check length of x-axis-labels of interaction variable and split 
   # longer strings into new lines
   if (!is.null(interactionVar)) {
     if (!is.null(interactionVarLabels)) {
-      interactionVarLabels <- sju.wordwrap(interactionVarLabels, breakLabelsAt)    
+      interactionVarLabels <- word_wrap(interactionVarLabels, breakLabelsAt)    
     }
     # If interaction-variable-labels were not defined, simply set numbers from 1 to
     # amount of categories instead
