@@ -24,13 +24,15 @@
 #'                of the data frame that belong to a certain factor (see return value of function \code{\link{sjt.pca}}
 #'                as example for retrieving factor groups for a scale and see examples for more details).
 #'
-#' @seealso \code{\link{sjs.cronbach}} \cr
-#'          \code{\link{sjs.reliability}} \cr
-#'          \code{\link{sjs.mic}} \cr
-#'          \code{\link{sjp.pca}} \cr
-#'          \code{\link{sjt.pca}} \cr
-#'          \code{\link{sjt.df}} \cr
-#'          \code{\link{sju.mean.n}}
+#' @seealso \itemize{
+#'            \item \code{\link{sjp.pca}}
+#'            \item \code{\link{sjt.pca}}
+#'            \item \code{\link{sjt.df}}
+#'            \item \code{\link{cronb}}
+#'            \item \code{\link{reliab_test}}
+#'            \item \code{\link{mic}}
+#'            \item \code{\link{mean_n}}
+#'            }
 #'          
 #' @param df A data frame with items (from a scale)
 #' @param factor.groups If not \code{NULL}, the data frame \code{df} will be splitted into sub-groups,
@@ -42,12 +44,12 @@
 #'          Default is \code{"auto"}, which means that each table has a standard caption \emph{Component x}.
 #'          Use \code{NULL} to suppress table captions.
 #' @param scaleItems If \code{TRUE}, the data frame's vectors will be scaled when calculating the
-#'          Cronbach's Alpha value (see \code{\link{sjs.reliability}}). Recommended, when 
+#'          Cronbach's Alpha value (see \code{\link{reliab_test}}). Recommended, when 
 #'          the variables have different measures / scales.
 #' @param minValidRowMeanValue the minimum amount of valid values to compute row means for index scores.
 #'          Default is 2, i.e. the return values \code{index.scores} and \code{df.index.scores} are
 #'          computed for those items that have at least \code{minValidRowMeanValue} per case (observation, or
-#'          technically, row). See \link{sju.mean.n} for details.
+#'          technically, row). See \link{mean_n} for details.
 #' @param alternateRowColors If \code{TRUE}, alternating rows are highlighted with a light gray
 #'          background color.
 #' @param orderColumn Indicates a column, either by column name or by column index number,
@@ -119,7 +121,7 @@
 #' @note \itemize{
 #'          \item The \emph{Shapiro-Wilk Normality Test} (see column \code{W(p)}) tests if an item has a distribution that is significantly different from normal.
 #'          \item \emph{Item difficulty} should range between 0.2 and 0.8. Ideal value is \code{p+(1-p)/2} (which mostly is between 0.5 and 0.8).
-#'          \item For \emph{item discrimination}, acceptable values are 0.20 or higher; the closer to 1.00 the better. See \code{\link{sjs.reliability}} for more details.
+#'          \item For \emph{item discrimination}, acceptable values are 0.20 or higher; the closer to 1.00 the better. See \code{\link{reliab_test}} for more details.
 #'          \item In case the total \emph{Cronbach's Alpha} value is below the acceptable cut-off of 0.7 (mostly if an index has few items), the \emph{mean inter-item-correlation} is an alternative measure to indicate acceptability. Satisfactory range lies between 0.2 and 0.4.
 #'        }
 #' 
@@ -137,7 +139,7 @@
 #' data(efc)
 #' 
 #' # retrieve variable and value labels
-#' varlabs <- sji.getVariableLabels(efc)
+#' varlabs <- get_var_labels(efc)
 #' 
 #' # recveive first item of COPE-index scale
 #' start <- which(colnames(efc)=="c82cop1")
@@ -154,7 +156,7 @@
 #' # -------------------------------
 #' # auto-detection of labels
 #' # -------------------------------
-#' efc <- sji.setVariableLabels(efc, varlabs)
+#' efc <- set_var_labels(efc, varlabs)
 #' sjt.itemanalysis(efc[,c(start:end)])
 #'   
 #' # ---------------------------------------
@@ -288,12 +290,12 @@ sjt.itemanalysis <- function(df,
     # -----------------------------------
     # get statistics
     # -----------------------------------
-    dstat <- describe(df.sub)
-    reli <- sjs.reliability(df.sub, scaleItems=scaleItems)
+    dstat <- psych::describe(df.sub)
+    reli <- reliab_test(df.sub, scaleItems=scaleItems)
     # -----------------------------------
     # get index score value, by retrieving the row mean
     # -----------------------------------
-    item.score <- sju.mean.n(df.sub, minValidRowMeanValue)
+    item.score <- mean_n(df.sub, minValidRowMeanValue)
     # -----------------------------------
     # store scaled values of each item's total score
     # to compute correlation coefficients between identified components
@@ -346,12 +348,12 @@ sjt.itemanalysis <- function(df,
     df.ia[[length(df.ia)+1]] <- df.dummy
     diff.ideal.list[[length(diff.ideal.list)+1]] <- diff.ideal
     index.scores[[length(index.scores)+1]] <- item.score
-    cronbach.total[[length(cronbach.total)+1]] <- sjs.cronbach(df.sub)
+    cronbach.total[[length(cronbach.total)+1]] <- cronb(df.sub)
     df.comcor[[length(df.comcor)+1]] <- comcor
     # -----------------------------------
     # Mean-interitem-corelation
     # -----------------------------------
-    mic.total[[length(mic.total)+1]] <- sjs.mic(df.sub)
+    mic.total[[length(mic.total)+1]] <- mic(df.sub)
   }
   # -----------------------------------
   # create data frame with index scores,
@@ -375,7 +377,17 @@ sjt.itemanalysis <- function(df,
     # check if we have titles for each component-table
     if (!is.null(factor.groups.titles)) dftitle <- factor.groups.titles[i]
     # get html-table from data frame
-    html <- sjt.df(df.ia[[i]], describe=FALSE, no.output=TRUE, title=dftitle, orderAscending=orderAscending, orderColumn=orderColumn, alternateRowColors=alternateRowColors, CSS=CSS, encoding=encoding, showCommentRow=TRUE, commentString=sprintf("Mean inter-item-correlation=%.3f &middot; Cronbach's &alpha;=%.3f", mic.total[[i]], cronbach.total[[i]]))
+    html <- sjt.df(df.ia[[i]], 
+                   describe = FALSE, 
+                   no.output = TRUE, 
+                   title = dftitle, 
+                   orderAscending = orderAscending, 
+                   orderColumn = orderColumn, 
+                   alternateRowColors = alternateRowColors, 
+                   CSS = CSS, 
+                   encoding = encoding, 
+                   showCommentRow = TRUE, 
+                   commentString = sprintf("Mean inter-item-correlation=%.3f &middot; Cronbach's &alpha;=%.3f", mic.total[[i]], cronbach.total[[i]]))
     # add to complete html-page
     complete.page <- paste0(complete.page, html$knitr)
     complete.page <- paste0(complete.page, "<p style=\"margin:2em;\">&nbsp;</p>")
@@ -392,7 +404,13 @@ sjt.itemanalysis <- function(df,
       # give proper columm names
       colnames(df.cc) <- sprintf("Component %i", c(1:ncol(df.cc)))
       # compute correlation table, store html result
-      html <- sjt.corr(df.cc, missingDeletion="listwise", pvaluesAsNumbers=TRUE, triangle="lower", stringDiagonal=sprintf("&alpha;=%.3f", unlist(cronbach.total)), encoding=encoding, no.output=TRUE)
+      html <- sjt.corr(df.cc, 
+                       missingDeletion = "listwise", 
+                       pvaluesAsNumbers = TRUE, 
+                       triangle = "lower", 
+                       stringDiagonal = sprintf("&alpha;=%.3f", unlist(cronbach.total)), 
+                       encoding = encoding, 
+                       no.output = TRUE)
       # add to html that is printed
       complete.page <- paste0(complete.page, html$knitr)
       knitr.list[[length(knitr.list)+1]] <- html$knitr
@@ -408,8 +426,7 @@ sjt.itemanalysis <- function(df,
   # -------------------------------------
   if (remove.spaces) {
     knitr <- sju.rmspc(knitr)
-    toWrite <- sju.rmspc(toWrite)
-    page.content <- sju.rmspc(page.content)
+    complete.page <- sju.rmspc(complete.page)
   }
   # -------------------------------------
   # check if html-content should be printed
